Name:           mapserver
Version:        5.6.5
Release:        1%{?dist}
Summary:        Environment for building spatially-enabled internet applications
Group:          Development/Tools
License:        BSD
URL:            http://mapserver.gis.umn.edu
Source:         http://download.osgeo.org/mapserver/mapserver-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires:       httpd
Requires:       bitstream-vera-sans-fonts

BuildRequires:  libXpm-devel readline-devel
BuildRequires:  httpd-devel php-devel libxslt-devel pam-devel fcgi-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  postgresql-devel mysql-devel java-1.6.0-openjdk-devel
BuildRequires:  java-devel swig > 1.3.24 java java-1.5.0-gcj-devel
BuildRequires:  geos-devel proj-devel gdal-devel agg-devel cairo-devel
BuildRequires:  php-devel freetype-devel gd-devel >= 2.0.16
BuildRequires:  python-devel curl-devel zlib-devel libxml2-devel
BuildRequires:  libjpeg-devel libpng-devel libtiff-devel fribidi-devel


%define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")

%description
Mapserver is an internet mapping program that converts GIS data to
map images in real time. With appropriate interface pages, 
Mapserver can provide an interactive internet map based on 
custom GIS data.

%package -n php-mapserver
Summary:        PHP/Mapscript map making extensions to PHP
Group:          Development/Languages
Requires:       httpd php-gd

%description -n php-mapserver
The PHP/Mapscript extension provides full map customization capabilities within
the PHP scripting language.


%package perl
Summary:        Perl/Mapscript map making extensions to Perl
Group:          Development/Languages
Requires:       %{name} = %{version}-%{release}
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description perl
The Perl/Mapscript extension provides full map customization capabilities
within the Perl programming language.

%package python
Summary:        Python/Mapscript map making extensions to Python
Group:          Development/Languages
Requires:       %{name} = %{version}-%{release}

%description python
The Python/Mapscript extension provides full map customization capabilities
within the Python programming language.

%package java
Summary:        Java/Mapscript map making extensions to Java
Group:          Development/Languages
Requires:       %{name} = %{version}-%{release}
Requires:       java-gcj-compat 

%description java
The Java/Mapscript extension provides full map customization capabilities
within the Java programming language.

%prep
%setup -q
# fix spurious perm bits
chmod -x tests/home.png
chmod -x mapscript/php3/php_mapscript.c
chmod -x mappluginlayer.c
chmod -x mapscript/php3/mapscript_i.c
chmod -x mapscript/php3/examples/test_writeshape.phtml
chmod -x mapscript/python/examples/*.py
chmod -x mapscript/python/tests/rundoctests.dist
chmod -x mapscript/perl/examples/*.pl
chmod -x mapscript/php3/README


# remove fonts
# alias as symlinks
rm -rf tests/vera/Vera.ttf
rm -rf tests/vera/VeraBd.ttf
pushd tests/vera/
ln -sf /usr/share/fonts/bitstream-vera/Vera.ttf Vera.ttf
ln -sf /usr/share/fonts/bitstream-vera/Verabd.ttf VeraBd.ttf
popd

%build

# fix a UTF-8 one
iconv -f ISO-8859-1 -t UTF-8 < \
mapscript/java/examples/QueryByAttributeUnicode.java > \
mapscript/java/examples/QueryByAttributeUnicode-tmp.java
mv -f mapscript/java/examples/QueryByAttributeUnicode-tmp.java \
mapscript/java/examples/QueryByAttributeUnicode.java

# fix gdal lookup
%{__sed} -i.libs -e 's|`\$GDAL_CONFIG --dep-libs`||' configure

%configure \
   --with-gd \
   --with-zlib \
   --with-tiff \
   --with-agg \
   --with-experimental-png \
   --with-freetype=%{_bindir}/freetype-config \
   --with-gdal=%{_bindir}/gdal-config \
   --with-ogr=%{_bindir}/gdal-config \
   --with-geos=%{_bindir}/geos-config \
   --with-cairo=yes \
   --with-proj \
   --with-wfs \
   --with-wcs \
   --with-sos \
   --with-wmsclient \
   --with-wfsclient \
   --with-xpm \
   --with-postgis=%{_bindir}/pg_config \
   --with-mygis=%{_bindir}/mysql_config \
   --with-curl-config=%{_bindir}/curl-config \
   --with-xml2-config=%{_bindir}/xml2-config \
   --with-php=`php-config --include-dir` \
   --with-fribidi-config=%{_libdir}/pkgconfig/fribidi.pc \
   --with-fastcgi=/usr \
   --without-pdf \
   --without-eppl \
   --with-threads \
   --enable-debug \
   --disable-runpath

# disable pgport library lookup.
for makefile in `find . -type f -name 'Makefile'`; do
sed -i 's|-lpgport||g' $makefile
done

# WARNING !!!
# using %{?_smp_mflags} may break build

make

# build perl
cd mapscript/perl
perl Makefile.PL
make

# build python
cd ../python
python setup.py build

# build java
cd ../java
make interface
make

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}/%{_sbindir}
mkdir -p %{buildroot}/%{_sysconfdir}/php.d
mkdir -p %{buildroot}%{_libdir}/php/modules
mkdir -p %{buildroot}/%{_bindir}
install -p -m 755 mapserv %{buildroot}/%{_sbindir}
install -p -m 755 shp2img %{buildroot}/%{_bindir}
install -p -m 755 shptree %{buildroot}/%{_bindir}
install -p -m 755 sortshp %{buildroot}/%{_bindir}
install -p -m 755 tile4ms %{buildroot}/%{_bindir}

install -p -m 755 mapscript/php3/php_mapscript.so %{buildroot}/%{_libdir}/php/modules/

# install perl module
pushd mapscript/perl
make DESTDIR=%{buildroot} pure_vendor_install
popd

# install python module
pushd mapscript/python
python setup.py install --root %{buildroot}
popd

# install java
mkdir -p %{buildroot}%{_javadir}
install -p -m 644 mapscript/java/mapscript.jar %{buildroot}%{_javadir}/

# install php config file
mkdir -p %{buildroot}%{_sysconfdir}/php.d/
cat > %{buildroot}%{_sysconfdir}/php.d/%{name}.ini <<EOF
; Enable %{name} extension module
extension=php_mapscript.so
EOF

# cleanup junks
for junk in {*.pod,*.bs,.packlist} ; do
find %{buildroot} -name "$junk" -exec rm -rf '{}' \;
done

# fix some exec bits
chmod 755 %{buildroot}/%{perl_vendorarch}/auto/mapscript/mapscript.so

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README COMMITERS GD-COPYING HISTORY.TXT  
%doc INSTALL MIGRATION_GUIDE.TXT
%doc symbols tests
%doc fonts
%{_bindir}/shp2img
%{_bindir}/shptree
%{_bindir}/sortshp
%{_bindir}/tile4ms
%{_sbindir}/mapserv

%files -n php-mapserver
%defattr(-,root,root)
%doc mapscript/php3/README
%doc mapscript/php3/examples
%config(noreplace) %{_sysconfdir}/php.d/%{name}.ini
%{_libdir}/php/modules/php_mapscript.so

%files perl
%defattr(-,root,root)
%doc mapscript/perl/examples
%dir %{perl_vendorarch}/auto/mapscript
%{perl_vendorarch}/auto/mapscript/*
%{perl_vendorarch}/mapscript.pm

%files python
%defattr(-,root,root)
%doc mapscript/python/README
%doc mapscript/python/examples
%doc mapscript/python/tests
%{python_sitearch}/*

%files java
%defattr(-,root,root)
%doc mapscript/java/README
%doc mapscript/java/examples
%doc mapscript/java/tests
%{_javadir}/*.jar

%changelog
* Mon Jul 26 2010 Devrim GÜNDÜZ <devrim@gunduz.org> - 5.6.5-1
- Update to 5.6.5, for various fixes described at:
  http://trac.osgeo.org/mapserver/browser/tags/rel-5-6-5/mapserver/HISTORY.TXT
  Also fixes CVE-2010-2539, CVE-2010-2540, per bz #617301 and #617312.

* Tue Mar 23 2010 Devrim GÜNDÜZ <devrim@gunduz.org> - 5.6.3-1
- Update to 5.6.3, for various fixes described at:
  http://trac.osgeo.org/mapserver/browser/tags/rel-5-6-3/mapserver/HISTORY.TXT

* Thu Mar 18 2010 Balint Cristian <cristian.balint@gmail.com> - 5.6.1-3
- fix bz#538198
- enable fastcgi

* Thu Mar 18 2010 Balint Cristian <cristian.balint@gmail.com> - 5.6.1-2
- fix bz#555480
- enable cairo

* Sun Jan 10 2010 Devrim GUNDUZ <devrim@commandprompt.com> - 5.6.1-1
- Update to 5.6.1, for various fixes described at:
  http://trac.osgeo.org/mapserver/browser/tags/rel-5-6-1/mapserver/HISTORY.TXT

* Fri Dec 25 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.6.0-1
- Update to 5.6.0

* Fri Dec 4 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.6.0-rc1-1
- Update to 5.6.0-rc1, which includes fixes described in:
  http://trac.osgeo.org/mapserver/browser/tags/rel-5-6-0-rc1/mapserver/HISTORY.TXT

* Mon Aug 31 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.4.2-1
- Update to 5.4.2, which fixes CVE-2009-0840 and various fixes
  described in :
  http://trac.osgeo.org/mapserver/browser/tags/rel-5-4-2/mapserver/HISTORY.TXT
 
* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 5.4.1-3
- rebuilt with new openssl

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 17 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.4.1-1
- Update to 5.4.1

* Sun Apr 26 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.4.0-1
- Update to 5.4.0

* Sun Apr 5 2009 Devrim GUNDUZ <devrim@commandprompt.com> - 5.2.2-1
- Update to 5.2.2 which fixes :
  CVE-2009-0839, CVE-2009-0840, CVE-2009-0841, CVE-2009-0842, 
  CVE-2009-0843, CVE-2009-1176, CVE-2009-1177.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.2.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 11 2009 Balint Cristian <cristian.balint@gmail.com> - 5.2.1-6
- fix vera font requirement

* Thu Feb 05 2009 Balint Cristian <cristian.balint@gmail.com> - 5.2.1-5
- fix email typo
- rebuild

* Thu Jan 29 2009 Balint Cristian <cristian.balint@gmail.com> - 5.2.1-4
- email change
- rebuild against new gdal

* Sat Jan 03 2009 Balint Cristian <rezso@rdsor.ro> 5.2.1-3
- require external fonts
- get rid of internal fonts

* Sat Dec 07 2008 Balint Cristian <rezso@rdsor.ro> 5.2.1-2
- enable agg render engine
- enable fribidi renderer
- build require agg-devel fribidi-devel

* Mon Dec 01 2008 Balint Cristian <rezso@rdsor.ro> 5.2.1-1
- new stable upstream

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 5.2.0-2
- Rebuild for Python 2.6

* Wed Jul 23 2008 Balint Cristian <rezso@rdsor.ro> 5.2.0-1
- new 5.2 series upstream

* Thu Jul 05 2008 Balint Cristian <rezso@rdsor.ro> 5.0.3-3
- address bz#453925

* Thu Jun 26 2008 Devrim GUNDUZ <devrim@commandprompt.com> - 5.0.3-2
- Rebuilt against Geos 3.0.0

* Thu Jun 12 2008 Balint Cristian <rezso@rdsor.ro> 5.0.3-1
- update to 5.0.3 bugfix release
- fix some rpmlint warnings

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 5.0.2-2
- Autorebuild for GCC 4.3

* Sat Feb 9 2008 Devrim GUNDUZ <devrim@commandprompt.com> - 5.0.2-1
- Update to 5.0.2

* Sat Jan 5 2008 Devrim GUNDUZ <devrim@commandprompt.com> - 5.0.0-2
- Update BR for java-devel, per Patrice Dumas

* Fri Jan 4 2008 Devrim GUNDUZ <devrim@commandprompt.com> - 5.0.0-1
- Update to 5.0.0
- Removed patch0, since it is already in upstream.
- Updated BRs

* Thu Dec 06 2007 Release Engineering <rel-eng at fedoraproject dot org> - 4.10.3-3
- Rebuild for deps

* Thu Aug 30 2007 Oliver Falk <oliver@linux-kernel.at> 4.10.3-2
- Add fix to include libmapserver (in some places), instead of
  libmap, that doesn't exist (anymore)

* Thu Aug 30 2007 Oliver Falk <oliver@linux-kernel.at> 4.10.3-1
- Update to fix bz#256561, CVE-2007-4542

* Fri May 11 2007 Balint Cristian <cbalint@redhat.com> 4.10.2-4
- update require list properly.

* Thu May 10 2007 Balint Cristian <cbalint@redhat.com> 4.10.2-3
- use macros if possible in spec

* Thu May 10 2007 Balint Cristian <cbalint@redhat.com> 4.10.2-2
- further fixups for inclusion

* Thu May 10 2007 Balint Cristian <cbalint@redhat.com> 4.10.2-1
- new upsream tarball (bugfix)
- further fixups for inclusion

* Tue Apr 24 2007 Balint Cristian <cbalint@redhat.com> 4.10.1-3
- further fixups for inclusion
- enable java

* Fri Mar 16 2007 Balint Cristian <cbalint@redhat.com> 4.10.1-2
- add docs

* Fri Mar 16 2007 Balint Cristian <cbalint@redhat.com> 4.10.1-1
- first package
